<?php

class SmogateSDK {
    private $appId;
    private $appSecret;
    private $notifyUrl;
    private $path;
    private $params = [];

	public function setAppId($appId)
	{
		$this->appId = $appId;
		return $this;
	}

	public function setAppSecret($appSecret)
	{
		$this->appSecret = $appSecret;
		return $this;
	}

	public function setNotifyUrl($notifyUrl)
	{
		$this->notifyUrl = $notifyUrl;
		return $this;
	}

	public function setPath($path)
	{
		$this->path = $path;
		return $this;
	}

	public function setParams($params = [])
	{
		$this->params = $params;
		return $this;
	}

	public function send()
	{
		if (!$this->path) throw new \Exception('請設置業務路徑');
		if (!$this->notifyUrl) throw new \Exception('請設置通知地址');

		$this->setParams(array_merge([
			'app_id' 			=> $this->appId,
			'notify_url'		=> $this->notifyUrl,
		], $this->params));
		$this->sign();

		$result = $this->request($this->params);
		
        if (isset($result['errors'])) throw new \Exception($result['errors'][array_keys($result['errors'])[0]][0]);
        if (isset($result['message'])) throw new \Exception($result['message']);

        return $result['data'];
	}
    
    private function request($data)
    {
    	$url = "https://{$this->appId}.vless.org{$this->path}";
        $curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $url);
		curl_setopt($curl, CURLOPT_HEADER, 0);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($curl, CURLOPT_POST, 1);
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data));
	    curl_setopt($curl, CURLOPT_HTTPHEADER, ["User-Agent: Smogate {$this->appId}", "content-type:application/json"]);
		$data = curl_exec($curl);
		curl_close($curl);
		return json_decode($data, true);
    }


	private function sign()
	{
		$params = $this->params;
		ksort($params);
		$params['sign'] = strtolower(md5(http_build_query($params) . $this->appSecret));
		$this->setParams($params);
	}

	public function verify($data)
	{
	    $sign = $data['sign'];
		unset($data['sign']);
		ksort($data);
		return strtolower(md5(http_build_query($data) . $this->appSecret)) === $sign;
	}


    public function isMobile()
    {
        return strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'mobile') !== false;
    }
}